@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play the tabla!
 
-our $VERSION = '0.0501';
+our $VERSION = '0.0502';
 
 use Moo;
 use File::ShareDir qw(dist_dir);
@@ -66,15 +66,13 @@ sub strike {
 
 
 sub double_strike {
-  my ($self, $bol, $dura, $baya, $daya) = @_;
+  my ($self, $bol, $dura) = @_;
     $dura ||= $self->quarter;
     my $bols = $self->patches->{$bol};
     my $patches = $self->patches->{ $bols->[0] };
-    $baya = $patches->[ int rand @$patches ]
-        if $patches && (!defined $baya || $baya < 0);
+    my $baya = $patches->[ int rand @$patches ];
     $patches = $self->patches->{ $bols->[1] };
-    $daya = $patches->[ int rand @$patches ]
-        if $patches && (!defined $daya || $daya < 0);
+    my $daya = $patches->[ int rand @$patches ];
     $self->note($dura, $baya, $daya);
 }
 
@@ -92,7 +90,7 @@ Music::Percussion::Tabla - Play the tabla!
 
 =head1 VERSION
 
-version 0.0501
+version 0.0502
 
 =head1 SYNOPSIS
 
@@ -111,7 +109,7 @@ version 0.0501
     $t->strike('ge');
     $t->rest($t->quarter);
   }
-  $t->dha($t->quarter, 65, 61);
+  $t->double_strike('dha', $t->quarter);
 
   $t->play_with_timidity;
   # OR:
@@ -124,37 +122,37 @@ drum sounds and the included soundfont file (which is B<4.1MB>).
 
 Here are my "non-tabla player" descriptions of the sounds:
 
-   # MIDI Bol  - Description
+   # MIDI Description
   ...
-   1  60  tin  - ringing mid
-   2  61  ti   - muted low
-   3  62  ?    - slap
-   4  63  tin  - ringing mid slap
-   5  64  ke   - low knock
-   6  65  ga   - muted ringing low
-   7  66  ge   - lower
-   8  67  ?    - low-up
-   9  68  ti   - muted slap
-  10  69  ?    - ringing low
-  11  70  ti   - flam slap
-  12  71  ta   - loud tap
-  13  72  ti   - lowest mute
-  14  73  tun  - ringing low
-  15  74  ?    - muted low
-  16  75  ta   - loud tap double
-  17  76  ge   - high-low
-  18  77  ke   - high slap
-  19  78  na   - tap
-  20  79  ?    - high knock
-  21  80  ?    - short low-up
-  22  81  na   - mid tap
-  23  82  ti   - muted tap
-  24  83  tin  - mid
-  25  84  ?    - muted
-  26  85  ta   - loud mid double
-  27  86  ti   - slightly more muted
-  28  87  tin  - low mid
-  29  88  tun  - ringing mid
+   1  60  ringing mid
+   2  61  muted low
+   3  62  slap
+   4  63  ringing mid slap
+   5  64  low knock
+   6  65  muted ringing low
+   7  66  lower
+   8  67  low-up
+   9  68  muted slap
+  10  69  ringing low
+  11  70  flam slap
+  12  71  loud tap
+  13  72  lowest mute
+  14  73  ringing low
+  15  74  muted low
+  16  75  loud tap double
+  17  76  high-low
+  18  77  high slap
+  19  78  tap
+  20  79  high knock
+  21  80  short low-up
+  22  81  mid tap
+  23  82  muted tap
+  24  83  mid
+  25  84  muted
+  26  85  loud mid double
+  27  86  slightly more muted
+  28  87  low mid
+  29  88  ringing mid
   ...
 
 To play patches by number (for the unknown bols, for instance), do
@@ -233,6 +231,10 @@ Double strike bols:
 Play a double-strike on the B<baya> and B<daya> drums for the given
 B<bol> and B<duration>.
 
+If the individual bols comprising the double-strike have more than one
+possible patch, one is chosen at random. If specific patches are
+desired, use the C<note> method with multiple patches.
+
 =head1 SEE ALSO
 
 The F<t/01-methods.t> and F<eg/*> programs in this distribution.
